@@ -9,6 +9,9 @@ use feature qw/postderef signatures/;
 no warnings qw/experimental::postderef experimental::signatures/;
 
 use Scalar::Util qw/weaken/;
+use Log::Log4perl qw(get_logger :levels);
+
+my $user_logger = get_logger('User');
 
 # checkUnused license is a idx check, not a content check
 
@@ -16,13 +19,14 @@ sub BUILD ($self, @args) {
     $self->SUPER::BUILD(@args);
 
     weaken($self);
-    $self-> add_check_content( sub { $self->check_unused_licenses(@_);} )
+    $self-> add_check_content( sub { $self->check_unused_licenses(@_);} );
+    return;
 }
 
-sub check_idx {
+sub check_idx { ## no critic (RequireArgUnpacking)
     my $self = shift;
-
     my %args      = @_ > 1 ? @_ : ( index => $_[0] );
+
     my $idx       = $args{index};
     my $silent    = $args{silent} || 0;
     my $check     = $args{check} || 'yes';
@@ -44,7 +48,7 @@ sub check_idx {
             my $warn = "License $idx is not used in Files: section";;
             $self->inc_fixes;
             push $self->{warning_hash}{$idx}->@*, $warn;
-            warn "$warn\n" unless $silent;
+            $user_logger->warn("$warn") unless $silent;
         }
     }
 
@@ -66,7 +70,7 @@ sub _get_unused_licenses ($self, @licenses) {
 
         next unless $names; # may be undef when user is filling values
 
-        my @sub_licenses = split /[,\s]+(?:or|and)[,\s]+/,$names;
+        my @sub_licenses = split m![,\s]+(?:or|and|and/or)[,\s]+!,$names;
         map { delete $unused{$_}; } @sub_licenses;
     }
 
@@ -85,6 +89,7 @@ sub check_unused_licenses ($self,$error, $warn, $fix = 0, $silent = 0) {
 
     my $msg =  "Unused license: @unused";
     push $warn->@*, $msg;
+    return;
 }
 
 sub prune_unused_licenses ($self, $silent = 0) {
@@ -97,5 +102,6 @@ sub prune_unused_licenses ($self, $silent = 0) {
     foreach my $lic (@unused) {
         $self->delete("$lic");
     }
+    return;
 }
 1;
