@@ -697,6 +697,13 @@ sub check_or_fix_essential_package {
         return;
     }
 
+    if ($pkg eq "apt") {
+        # apt package is wrongly listed by apt-cache as essential, so it
+        # must be filtered out here. For details, see
+        # https://salsa.debian.org/perl-team/modules/packages/libconfig-model-dpkg-perl/-/merge_requests/8
+        return;
+    }
+
     # Remove unversioned dependency on essential package (Debian bug 684208)
     # see /usr/share/doc/libapt-pkg-perl/examples/apt-cache
 
