@@ -1,4 +1,7 @@
-[
+use strict;
+use warnings;
+
+return [
   {
     'author' => [
       'Dominique Dumont'
