@@ -34,12 +34,14 @@ A package may specify an architecture wildcard. Architecture wildcards are in th
       'Multi-Arch',
       {
         'choice' => [
+          'no',
           'same',
           'foreign',
           'allowed'
         ],
         'description' => 'This field is used to indicate how this package should behave on a multi-arch installations. This field should not be present in packages with the Architecture: all field.',
         'help' => {
+          'no' => 'the package is not co-installable and it must not be used to satisfy the dependency of any package of another architecture than its own.',
           'allowed' => 'allows reverse-dependencies to indicate in their Depends field that they need a package from a foreign architecture, but has no effect otherwise.',
           'foreign' => 'the package is not co-installable with itself, but should be allowed to satisfy the dependency of a package of a different arch from itself.',
           'same' => 'the package is co-installable with itself, but it must not be used to satisfy the dependency of any package of a different architecture from itself.'
@@ -149,7 +151,6 @@ packages that might be necessary for booting the system.
         },
         'migrate_from' => {
           'formula' => '$xbi',
-          'undef_is' => '0',
           'variables' => {
             'xbi' => '- XB-Important'
           }
