@@ -9,7 +9,13 @@ return [
       {
         'cargo' => {
           'type' => 'leaf',
-          'value_type' => 'uniline'
+          'value_type' => 'uniline',
+          'warn_if_match' => {
+            '(^|\\s)/' => {
+              'fix' => 's!(^|\\s)/!$1!g',
+              'msg' => 'path should not begin with \'/\''
+            }
+          }
         },
         'description' => 'a file or files to install. The end of the line tells the directory it
 should be installed in. The name of the files (or directories) to
@@ -34,7 +40,7 @@ See L<debhelper(7)> and L<dh_install> for more details.
       'auto_delete' => '1',
       'backend' => 'Dpkg::DebHelperFile',
       'config_dir' => 'debian',
-      'file' => 'install'
+      'file' => '&element(-)'
     }
   }
 ]
