@@ -1,4 +1,7 @@
-[
+use strict;
+use warnings;
+
+return [
   {
     'accept' => [
       'Bug-.*',
@@ -26,7 +29,7 @@ field',
         },
         'warn_unless' => {
           'empty' => {
-            'code' => 'defined $_ && /\\w/ ? 1 : 0 ;',
+            'code' => '(defined $_ && /\\w/ ) or ($self->grab_value(\'- Subject\') =~ /\\w/) ;',
             'fix' => 'my $node = $self->parent;
 $_ = ucfirst( $node->index_value // $node->instance->backend_arg // \'please fill synopsis\' )  ;
 s/-/ /g;
@@ -46,7 +49,7 @@ s/^\\d+\\s*//;
       'Subject',
       {
         'type' => 'leaf',
-        'value_type' => 'string'
+        'value_type' => 'uniline'
       },
       'Bug',
       {
