@@ -374,8 +374,10 @@ sub data_to_record ($self, $data) {
         $cop_str .= " ". $full_lic ."\n" ;
     }
 
-    # comment are not supported here, as comment are not generated by
-    # licensecheck
+    if (my $comment = $data->{Comment}) {
+        $cop_str .= "Comment: $comment\n";
+    }
+
     return $cop_str;
 }
 
