@@ -401,6 +401,14 @@ my @tests = (
             'source Build-Depends:2' => 'debhelper-compat (= 13)',
             'source Build-Depends:3' => qr/libcam-dev/,
         }
+    },
+    {
+        name => 'cpuinfo-with-multi-arch-no',
+        check => {
+            'source Rules-Requires-Root' => 'no',
+            'binary:cpuinfo Multi-Arch' => 'no',
+            'binary:cpuinfo Architecture' => 'amd64 arm64 armel armhf i386 x32 riscv64',
+        }
     }
 );
 
