@@ -1,14 +1,8 @@
-use Data::Dumper;
-use IO::File;
-use File::HomeDir ;
+use strict;
+use warnings;
 
-$conf_file_name = '';
-$conf_dir       = 'debian/patches';
-
-$model_to_test  = "Dpkg::Patches";
-
-@tests = (
-    { 
+my @tests = (
+    {
         name => 'debian-748502' ,
         # required to skip the bad patch (non dep-3)
         load_check => 'no',
@@ -23,5 +17,7 @@ $model_to_test  = "Dpkg::Patches";
     }
 );
 
-
-1;
+return {
+    conf_dir => 'debian/patches',
+    tests => \@tests,
+};
